@@ -3,19 +3,12 @@ package Search::Query;
 use warnings;
 use strict;
 use Search::Query::Parser;
-use Carp;
-use File::Find;
-use File::Spec;
-use Data::Dump qw( dump );
-use Module::Pluggable
-    search_path => ['Search::Query::Dialect'],
-    sub_name    => 'dialects';
 
-our $VERSION = '0.290_02';
+our $VERSION = '0.01';
 
 =head1 NAME
 
-Search::Query - polyglot query parsing
+Search::Query - polyglot query parsing, with dialects
 
 =head1 SYNOPSIS
 
@@ -29,18 +22,16 @@ Search::Query - polyglot query parsing
 
 =head1 DESCRIPTION
 
-This class provides documentation and class methods.
+This class provides documentation and a single class method.
 
-Search::Query started as a fork of the excellent Search::QueryParser module
+This module started as a fork of the excellent Search::QueryParser module
 and was then rewritten to provide support for alternate query dialects.
 
 =head1 METHODS
 
 =head2 parser
 
-Returns a Search::Query::Parser object. See the documentation
-for L<Search::Query::Parser> for supported query syntax and how
-to customize the Parser.
+Returns a Search::Query::Parser object.
 
 =cut
 
@@ -49,38 +40,6 @@ sub parser {
     return Search::Query::Parser->new(@_);
 }
 
-=head2 get_query_class( I<name> )
-
-Returns a Search::Query::Dialect-based class name corresponding
-to I<name>. I<name> defaults to 'Native'.
-
-=cut
-
-sub get_query_class {
-    my $class = shift;
-    my $name = shift or croak "query_class name required";
-
-    return $name if $name =~ m/^Search::Query::Dialect::/;
-
-    for my $dialect ( $class->dialects ) {
-        if ( $dialect =~ m/::$name$/i ) {
-            eval "require $dialect";
-            croak $@ if $@;
-            return $dialect;
-        }
-    }
-
-    croak "No such Dialect available: $name";
-}
-
-=head2 get_dialect( I<name> )
-
-Alias for get_query_class().
-
-=cut
-
-*get_dialect = \&get_query_class;
-
 =head1 AUTHOR
 
 Peter Karman, C<< <karman at cpan.org> >>
