@@ -5,8 +5,6 @@ use base qw( Search::Query::Dialect );
 use Carp;
 use Data::Dump qw( dump );
 
-our $VERSION = '0.290_02';
-
 =head1 NAME
 
 Search::Query::Dialect::Native - the default query dialect
@@ -33,74 +31,34 @@ Returns the Query object as a normalized string.
 =cut
 
 sub stringify {
-    my $self      = shift;
-    my $tree      = shift || $self;
-    my $no_prefix = shift || 0;
+    my $self = shift;
+    my $q = shift || $self;
 
-    my @q;
+    my @leaves;
     foreach my $prefix ( '+', '', '-' ) {
-        next unless exists $tree->{$prefix};
-        for my $clause ( @{ $tree->{$prefix} } ) {
-            push @q,
-                ( $no_prefix ? '' : $prefix )
-                . $self->stringify_clause($clause);
+        next if not $q->{$prefix};
+        for my $leaf ( @{ $q->{$prefix} } ) {
+            push @leaves, $prefix . $self->stringify_leaf($leaf);
         }
     }
 
-    return join " ", @q;
+    return join " ", @leaves;
 }
 
-=head2 stringify_clause( I<leaf> )
+=head2 stringify_leaf( I<leaf> )
 
-Called by stringify() to handle each Clause in the Query tree.
+Called by stringify() to handle each leaf in the Query tree.
 
 =cut
 
-sub stringify_clause {
-    my $self   = shift;
-    my $clause = shift;
+sub stringify_leaf {
+    my $self = shift;
+    my $leaf = shift;
 
-    if ( $clause->{op} eq '()' ) {
-        if ( $clause->has_children and $clause->has_children == 1 ) {
-            return $self->stringify( $clause->{value}, 1 );
-        }
-        else {
-            return "(" . $self->stringify( $clause->{value} ) . ")";
-        }
-    }
-
-    my $quote     = $clause->quote || "";
-    my $value     = $clause->value;
-    my $proximity = $clause->proximity || '';
-    if ($proximity) {
-        $proximity = '~' . $proximity;
-    }
-
-    # ranges
-    if ( ref $value eq 'ARRAY' ) {
-        $value = join( qq/$quote $quote/, $value->[0] .. $value->[1] );
-        if ( $clause->{op} eq '!..' ) {
-            return join( '',
-                ( defined $clause->{field} ? $clause->{field} : "" ),
-                '!=', '(', $quote, $value, $quote, ')' );
-        }
-        elsif ( $clause->{op} eq '..' ) {
-            return join( '',
-                ( defined $clause->{field} ? $clause->{field} : "" ),
-                '=', '(', $quote, $value, $quote, ')' );
-        }
-    }
-
-    # NULL query
-    elsif ( defined $clause->{field} and !defined $value ) {
-        return sprintf( "%s %s NULL",
-            $clause->{field}, ( $clause->{op} eq '=' ? 'is' : 'is not' ) );
-    }
-    else {
-        return join( '',
-            ( defined $clause->{field} ? $clause->{field} : "" ),
-            $clause->{op}, $quote, $value, $quote, $proximity );
-    }
+    return "(" . $self->stringify( $leaf->{value} ) . ")"
+        if $leaf->{op} eq '()';
+    my $quote = $leaf->{quote} || "";
+    return "$leaf->{field}$leaf->{op}$quote$leaf->{value}$quote";
 }
 
 1;
